--
-- adjustWorkareas
-- Specialization for adjustWorkareas
--
-- monteur1

adjustWorkareas = {};

function adjustWorkareas.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(WorkArea, specializations);
end

function adjustWorkareas:load(xmlFile)
    self.adjustWorkareasLeft  = Utils.indexToObject(self.components, getXMLString(self.xmlFile, "vehicle.adjustWorkAreaIndex#startIndex"));	
    self.adjustWorkareasRight = Utils.indexToObject(self.components, getXMLString(self.xmlFile, "vehicle.adjustWorkAreaIndex#widthIndex"));	
    self.adjustWorkareasBack  = Utils.indexToObject(self.components, getXMLString(self.xmlFile, "vehicle.adjustWorkAreaIndex#heightIndex"));
	
    self.adjustOnSelfAttaching  = Utils.getNoNil(getXMLBool(self.xmlFile, "vehicle.adjustWorkAreaIndex#adjustOnSelfAttaching"), false);	
	self.adjustWorkareasNowAdjust = false
	
	self.calcWorkingWidth = adjustWorkareas.calcWorkingWidth;
end

function adjustWorkareas:postLoad(savegame)
end

function adjustWorkareas:getSaveAttributesAndNodes(nodeIdent)
end

function adjustWorkareas:readStream(streamId, connection)
    if connection:getIsServer() then
		self.adjustWorkareasNowAdjust = streamReadBool(streamId); 
	end
end

function adjustWorkareas:writeStream(streamId, connection)
    if not connection:getIsServer() then
		streamWriteBool(streamId, self.adjustWorkareasNowAdjust);	
	end
end

function adjustWorkareas:update(dt)
	if self.adjustWorkareasNowAdjust == true then
		setTranslation(self.adjustWorkareasLeft, self.adjustWorkareasX1, 0, 0);
		setTranslation(self.adjustWorkareasRight, self.adjustWorkareasX2, 0, 0);
		setTranslation(self.adjustWorkareasBack, self.adjustWorkareasX3, 0, -1);
		self.adjustWorkareasNowAdjust = false
	end
end

function adjustWorkareas:draw()
end

function adjustWorkareas:delete()
end;

function adjustWorkareas:mouseEvent(posX, posY, isDown, isUp, button)
end;

function adjustWorkareas:keyEvent(unicode, sym, modifier, isDown)
end;

function adjustWorkareas:onAttach(attacherVehicle)
	if self.adjustOnSelfAttaching == true then
		self.attachedTool = attacherVehicle;
		if self.attachedTool ~= nil then
			self:calcWorkingWidth()		
		end
	end	
end

function adjustWorkareas:onAttachImplement(implement)	
	if self.adjustOnSelfAttaching == false then
		for _,implement in pairs(self.attachedImplements) do
			if implement.object ~= nil then
				self.attachedTool = implement.object
				if self.attachedTool ~= nil then
					self:calcWorkingWidth()				
				end
			end
		end
	end
end;

function adjustWorkareas:calcWorkingWidth()
----	 Sprayer Application Rate calc Workingwidth-----------------------------	
	local xmin = 200;
	local xmax = -200;
	if self.attachedTool.workAreas ~= nil then
		for _,workAreas in pairs(self.attachedTool.workAreas) do							
			local x1,y1,z1 = getWorldTranslation(workAreas.start)
			local x2,y2,z2 = getWorldTranslation(workAreas.width)
			local x3,y3,z3 = getWorldTranslation(workAreas.height)
			local lx1,ly1,lz1 = worldToLocal(self.attachedTool.rootNode,x1,y1,z1)
			local lx2,ly2,lz2 = worldToLocal(self.attachedTool.rootNode,x2,y2,z2)
			local lx3,ly3,lz3 = worldToLocal(self.attachedTool.rootNode,x3,y3,z3)
											
			if lx1 < xmin then
				xmin = lx1;
			end
			if lx1 > xmax then
				xmax = lx1;
			end
			if lx2 < xmin then
				xmin = lx2;
			end
			if lx2 > xmax then
				xmax = lx2;
			end
			if lx3 < xmin then
				xmin = lx3;
			end
			if lx3 > xmax then
				xmax = lx3;
			end
								
			self.adjustWorkareasX1 = xmin --lx1
			self.adjustWorkareasX2 = xmax --lx2
			self.adjustWorkareasX3 = xmin --lx3
			self.adjustWorkareasNowAdjust = true			
		end	
	else
		self.adjustWorkareasNowAdjust = false			
	end					
----	 Sprayer Application Rate calc Ende -----------------------------	
end; 	
